/// <reference path="./custom.d.ts" />
// tslint:disable
/**
 * NWS Warnings - A Weather Source API
 * NWS advisories, watches and warnings for latitude/longitude points and OnPoint™ points. The Weather Source NWS Warnings API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.      **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This file is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the file manually.
 */

import * as url from "url";
import * as isomorphicFetch from "isomorphic-fetch";
import { Configuration } from "./configuration";

const BASE_PATH = "https://nwswarnings.weathersourceapis.com/v2".replace(/\/+$/, "");

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
    csv: ",",
    ssv: " ",
    tsv: "\t",
    pipes: "|",
};

/**
 *
 * @export
 * @interface FetchAPI
 */
export interface FetchAPI {
    (url: string, init?: any): Promise<Response>;
}

/**
 *
 * @export
 * @interface FetchArgs
 */
export interface FetchArgs {
    url: string;
    options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
    protected configuration: Configuration;

    constructor(configuration?: Configuration, protected basePath: string = BASE_PATH, protected fetch: FetchAPI = isomorphicFetch) {
        if (configuration) {
            this.configuration = configuration;
            this.basePath = configuration.basePath || this.basePath;
        }
    }
};

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
    name: "RequiredError"
    constructor(public field: string, msg?: string) {
        super(msg);
    }
}

/**
 * A list of OnPoint™ points related to the location
 * @export
 */
export type BoundingPoints = Array<BoundingPointsInner>
/**
 * 
 * @export
 * @interface BoundingPointsInner
 */
export interface BoundingPointsInner {
    /**
     * 
     * @type {OnpointId}
     * @memberof BoundingPointsInner
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof BoundingPointsInner
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof BoundingPointsInner
     */
    longitude: Longitude;
    /**
     * 
     * @type {Grid}
     * @memberof BoundingPointsInner
     */
    grid: Grid;
    /**
     * 
     * @type {Distance}
     * @memberof BoundingPointsInner
     */
    distance: Distance;
    /**
     * 
     * @type {Elevation}
     * @memberof BoundingPointsInner
     */
    elevation: Elevation;
}
/**
 * An [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
 * @export
 */
export type CountryCode = string
/**
 * A common country name.
 * @export
 */
export type CountryName = string
/**
 * A distance from the provided point in miles.
 * @export
 */
export type Distance = number
/**
 * The elevation above sea level of a location in meters
 * @export
 */
export type Elevation = number
/**
 * 
 * @export
 * @interface ErrorObj
 */
export interface ErrorObj {
    /**
     * 
     * @type {number}
     * @memberof ErrorObj
     */
    errorCode?: number;
    /**
     * 
     * @type {string}
     * @memberof ErrorObj
     */
    errorMessage?: string;
}
/**
 * A list of returned field names the associated units.
 * @export
 * @interface FieldListObj
 */
export interface FieldListObj {
    /**
     * 
     * @type {Fields}
     * @memberof FieldListObj
     */
    fields: Fields;
}
/**
 * 
 * @export
 * @interface Fields
 */
export interface Fields extends null<String, string> {
    [key: string]: string;

}
/**
 * The OnPoint™ grid on which the resource exists.
 * @export
 * @enum {string}
 */
export enum Grid {
    GLOBALGRID = <any> 'GLOBAL_GRID',
    NORTHAMERICAGRID = <any> 'NORTH_AMERICA_GRID'
}
/**
 * A latitude value between -90° and 90°.
 * @export
 */
export type Latitude = number
/**
 * A longitude value between -180° (West) and 180° (East).
 * @export
 */
export type Longitude = number
/**
 * An array of NWS Warnings objects.
 * @export
 */
export type NwsWarningsArr = Array<NwsWarningsObj>
/**
 * A NWS Warnings object.
 * @export
 * @interface NwsWarningsObj
 */
export interface NwsWarningsObj {
    /**
     * 
     * @type {TimestampExpires}
     * @memberof NwsWarningsObj
     */
    timestampExpires: TimestampExpires;
    /**
     * 
     * @type {PhenomCode}
     * @memberof NwsWarningsObj
     */
    phenomCode: PhenomCode;
    /**
     * 
     * @type {PhenomDesc}
     * @memberof NwsWarningsObj
     */
    phenomDesc: PhenomDesc;
    /**
     * 
     * @type {Significance}
     * @memberof NwsWarningsObj
     */
    significance: Significance;
}
/**
 * OnPoint™ point NWS Warnings object
 * @export
 * @interface NwsWarningsOnpointObj
 */
export interface NwsWarningsOnpointObj {
    /**
     * 
     * @type {OnpointObj}
     * @memberof NwsWarningsOnpointObj
     */
    location: OnpointObj;
    /**
     * 
     * @type {FieldListObj}
     * @memberof NwsWarningsOnpointObj
     */
    fieldList: FieldListObj;
    /**
     * 
     * @type {NwsWarningsArr}
     * @memberof NwsWarningsOnpointObj
     */
    warniungs?: NwsWarningsArr;
}
/**
 * Latitude/Longitude NWS Warnings object
 * @export
 * @interface NwsWarningsPointObj
 */
export interface NwsWarningsPointObj {
    /**
     * 
     * @type {PointObj}
     * @memberof NwsWarningsPointObj
     */
    location: PointObj;
    /**
     * 
     * @type {FieldListObj}
     * @memberof NwsWarningsPointObj
     */
    fieldList: FieldListObj;
    /**
     * 
     * @type {NwsWarningsArr}
     * @memberof NwsWarningsPointObj
     */
    warnings: NwsWarningsArr;
}
/**
 * An OnPoint™ ID.
 * @export
 */
export type OnpointId = number
/**
 * An OnPoint™ point location metadata object
 * @export
 * @interface OnpointObj
 */
export interface OnpointObj {
    /**
     * 
     * @type {OnpointId}
     * @memberof OnpointObj
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof OnpointObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof OnpointObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof OnpointObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof OnpointObj
     */
    countryCode?: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof OnpointObj
     */
    countryName?: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof OnpointObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof OnpointObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {Grid}
     * @memberof OnpointObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof OnpointObj
     */
    elevation: Elevation;
}
/**
 * A 2-character string indicating the phenomena for which the advisory, watch, or warning was issued.
 * @export
 * @enum {string}
 */
export enum PhenomCode {
    AF = <any> 'AF',
    AS = <any> 'AS',
    BH = <any> 'BH',
    BW = <any> 'BW',
    BZ = <any> 'BZ',
    CF = <any> 'CF',
    DF = <any> 'DF',
    DS = <any> 'DS',
    DU = <any> 'DU',
    EC = <any> 'EC',
    EH = <any> 'EH',
    EW = <any> 'EW',
    FA = <any> 'FA',
    FF = <any> 'FF',
    FG = <any> 'FG',
    FL = <any> 'FL',
    FR = <any> 'FR',
    FW = <any> 'FW',
    FZ = <any> 'FZ',
    GL = <any> 'GL',
    HF = <any> 'HF',
    HT = <any> 'HT',
    HU = <any> 'HU',
    HW = <any> 'HW',
    HY = <any> 'HY',
    HZ = <any> 'HZ',
    IS = <any> 'IS',
    LE = <any> 'LE',
    LO = <any> 'LO',
    LS = <any> 'LS',
    LW = <any> 'LW',
    MA = <any> 'MA',
    MF = <any> 'MF',
    MH = <any> 'MH',
    MS = <any> 'MS',
    RP = <any> 'RP',
    SC = <any> 'SC',
    SE = <any> 'SE',
    SM = <any> 'SM',
    SQ = <any> 'SQ',
    SR = <any> 'SR',
    SS = <any> 'SS',
    SU = <any> 'SU',
    SV = <any> 'SV',
    TO = <any> 'TO',
    TR = <any> 'TR',
    TS = <any> 'TS',
    TY = <any> 'TY',
    UP = <any> 'UP',
    WC = <any> 'WC',
    WI = <any> 'WI',
    WS = <any> 'WS',
    WW = <any> 'WW',
    ZF = <any> 'ZF',
    ZY = <any> 'ZY'
}
/**
 * Description of the phenomena for which the advisory, watch, or warning was issued.
 * @export
 * @enum {string}
 */
export enum PhenomDesc {
    AshfallLand = <any> 'Ashfall (land)',
    AirStagnation = <any> 'Air Stagnation',
    BeachHazard = <any> 'Beach Hazard',
    BriskWind = <any> 'Brisk Wind',
    Blizzard = <any> 'Blizzard',
    CoastalFlood = <any> 'Coastal Flood',
    DebrisFlow = <any> 'Debris Flow',
    DustStorm = <any> 'Dust Storm',
    BlowingDust = <any> 'Blowing Dust',
    ExtremeCold = <any> 'Extreme Cold',
    ExcessiveHeat = <any> 'Excessive Heat',
    ExtremeWind = <any> 'Extreme Wind',
    Flood = <any> 'Flood',
    FlashFlood = <any> 'Flash Flood',
    DenseFogLand = <any> 'Dense Fog (land)',
    FloodForecastPoint = <any> 'Flood (forecast point)',
    Frost = <any> 'Frost',
    FireWeather = <any> 'Fire Weather',
    Freeze = <any> 'Freeze',
    Gale = <any> 'Gale',
    HurricaneForceWind = <any> 'Hurricane Force Wind',
    Heat = <any> 'Heat',
    Hurricane = <any> 'Hurricane',
    HighWind = <any> 'High Wind',
    Hydrologic = <any> 'Hydrologic',
    HardFreeze = <any> 'Hard Freeze',
    IceStorm = <any> 'Ice Storm',
    LakeEffectSnow = <any> 'Lake Effect Snow',
    LowWater = <any> 'Low Water',
    LakeshoreFlood = <any> 'Lakeshore Flood',
    LakeWind = <any> 'Lake Wind',
    Marine = <any> 'Marine',
    DenseFogMarine = <any> 'Dense Fog (marine)',
    AshfallMarine = <any> 'Ashfall (marine)',
    DenseSmokeMarine = <any> 'Dense Smoke (marine)',
    RipCurrentRisk = <any> 'Rip Current Risk',
    SmallCraft = <any> 'Small Craft',
    HazardousSeas = <any> 'Hazardous Seas',
    DenseSmokeLand = <any> 'Dense Smoke (land)',
    SnowSquall = <any> 'Snow Squall',
    Storm = <any> 'Storm',
    StormSurge = <any> 'Storm Surge',
    HighSurf = <any> 'High Surf',
    SevereThunderstorm = <any> 'Severe Thunderstorm',
    Tornado = <any> 'Tornado',
    TropicalStorm = <any> 'Tropical Storm',
    Tsunami = <any> 'Tsunami',
    Typhoon = <any> 'Typhoon',
    HeavyFreezingSpray = <any> 'Heavy Freezing Spray',
    WindChill = <any> 'Wind Chill',
    Wind = <any> 'Wind',
    WinterStorm = <any> 'Winter Storm',
    WinterWeather = <any> 'Winter Weather',
    FreezingFog = <any> 'Freezing Fog',
    FreezingSpray = <any> 'Freezing Spray'
}
/**
 * Metadata object for a postcode
 * @export
 * @interface PointObj
 */
export interface PointObj {
    /**
     * 
     * @type {Latitude}
     * @memberof PointObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof PointObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof PointObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof PointObj
     */
    countryCode?: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof PointObj
     */
    countryName?: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof PointObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof PointObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {BoundingPoints}
     * @memberof PointObj
     */
    boundingPoints: BoundingPoints;
    /**
     * 
     * @type {Grid}
     * @memberof PointObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof PointObj
     */
    elevation: Elevation;
}
/**
 * The risk significance for the phenomona.
 * @export
 * @enum {string}
 */
export enum Significance {
    ADVISORY = <any> 'ADVISORY',
    WATCH = <any> 'WATCH',
    WARNING = <any> 'WARNING'
}
/**
 * An ISO 3166-2 country subdivision code.
 * @export
 */
export type SubdivCode = string
/**
 * A common country subdivision name.
 * @export
 */
export type SubdivName = string
/**
 * A timestamp formatted as an RFC3339 date-time value that indicates when the advisory, watch, or warning expires.
 * @export
 */
export type TimestampExpires = Date
/**
 * An Olson timezone ID.
 * @export
 */
export type Timezone = string
/**
 * OnpointsApi - fetch parameter creator
 * @export
 */
export const OnpointsApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns NWS advisories, watches and warnings data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary NWS advisories, watches and warnings for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdGet(onpointId: number, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdGet.');
            }
            const localVarPath = `/onpoints/{onpointId}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * OnpointsApi - functional programming interface
 * @export
 */
export const OnpointsApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns NWS advisories, watches and warnings data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary NWS advisories, watches and warnings for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdGet(onpointId: number, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<NwsWarningsOnpointObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdGet(onpointId, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * OnpointsApi - factory interface
 * @export
 */
export const OnpointsApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns NWS advisories, watches and warnings data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary NWS advisories, watches and warnings for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdGet(onpointId: number, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdGet(onpointId, options)(fetch, basePath);
        },
    };
};

/**
 * OnpointsApi - object-oriented interface
 * @export
 * @class OnpointsApi
 * @extends {BaseAPI}
 */
export class OnpointsApi extends BaseAPI {
    /**
     * Returns NWS advisories, watches and warnings data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary NWS advisories, watches and warnings for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdGet(onpointId: number, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdGet(onpointId, options)(this.fetch, this.basePath);
    }

}
/**
 * PointsApi - fetch parameter creator
 * @export
 */
export const PointsApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns NWS advisories, watches and warnings data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary NWS advisories, watches and warnings for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeGet(latitude: number, longitude: number, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * PointsApi - functional programming interface
 * @export
 */
export const PointsApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns NWS advisories, watches and warnings data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary NWS advisories, watches and warnings for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeGet(latitude: number, longitude: number, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<NwsWarningsPointObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeGet(latitude, longitude, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * PointsApi - factory interface
 * @export
 */
export const PointsApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns NWS advisories, watches and warnings data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary NWS advisories, watches and warnings for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeGet(latitude: number, longitude: number, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeGet(latitude, longitude, options)(fetch, basePath);
        },
    };
};

/**
 * PointsApi - object-oriented interface
 * @export
 * @class PointsApi
 * @extends {BaseAPI}
 */
export class PointsApi extends BaseAPI {
    /**
     * Returns NWS advisories, watches and warnings data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary NWS advisories, watches and warnings for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeGet(latitude: number, longitude: number, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeGet(latitude, longitude, options)(this.fetch, this.basePath);
    }

}
